@@ -2,7 +2,7 @@ use 5.006;
 use strict;
 use warnings;
 package Muldis::D;
-our $VERSION = '0.148001';
+our $VERSION = '0.148002';
 $VERSION = eval $VERSION;
 # Note that Perl code only exists at all in this file in order to help
 # the CPAN indexer handle the distribution properly.
@@ -20,19 +20,19 @@ Formal spec of Muldis D relational DBMS lang
 
 =head1 VERSION
 
-This document is Muldis::D version 0.148.1.
+This document is Muldis::D version 0.148.2.
 
 =head1 PREFACE
 
 This is the root document of the Muldis D language specification; the
 documents that comprise the remaining parts of the specification, in their
 suggested reading order (but that all follow the root), are:
-L<Muldis::D::Basics>, L<Muldis::D::Core> (which has its own tree of parts
-to follow), L<Muldis::D::Dialect::PTMD_STD>,
-L<Muldis::D::Dialect::HDMD_Perl6_STD>,
-L<Muldis::D::Dialect::HDMD_Perl5_STD>, L<Muldis::D::Conventions>,
-L<Muldis::D::Ext::Counted>, L<Muldis::D::Ext::Temporal>,
-L<Muldis::D::Ext::Spatial>.
+L<Muldis::D::Outdated::Basics>, L<Muldis::D::Outdated::Core> (which has its own tree of parts
+to follow), L<Muldis::D::Outdated::Dialect::PTMD_STD>,
+L<Muldis::D::Outdated::Dialect::HDMD_Perl6_STD>,
+L<Muldis::D::Outdated::Dialect::HDMD_Perl5_STD>, L<Muldis::D::Outdated::Conventions>,
+L<Muldis::D::Outdated::Ext::Counted>, L<Muldis::D::Outdated::Ext::Temporal>,
+L<Muldis::D::Outdated::Ext::Spatial>.
 
 =head1 DESCRIPTION
 
@@ -45,9 +45,9 @@ at them.
 
 The fully-qualified name of this multi-part document and the language
 specification it contains (as a single composition) is
-C<Muldis_D:"http://muldis.com":0.148.1>.  It is the official/original (not
+C<Muldis_D:"http://muldis.com":0.148.2>.  It is the official/original (not
 embraced and extended) Muldis D language specification by the authority
-Muldis Data Systems (C<http://muldis.com>), version C<0.148.1> (this number
+Muldis Data Systems (C<http://muldis.com>), version C<0.148.2> (this number
 matches the VERSION pod in this file).  This multi-part document is named
 and organized with the expectation that many dialects, extensions, and core
 versions of it will exist over time, some of those under the original
@@ -101,7 +101,7 @@ In any event, the Muldis D documentation will be focusing mainly on how
 Muldis D itself works, and will spend little time in providing rationale;
 you can read the aforementioned external documentation for much of that.
 
-Continue reading the language spec in L<Muldis::D::Basics>.
+Continue reading the language spec in L<Muldis::D::Outdated::Basics>.
 
 Also look at the separately distributed L<Muldis::Rosetta>, which is the
 first main implementation of Muldis D.
@@ -266,8 +266,8 @@ code's behavior.
 
 See the following parts of the current multi-document for descriptions of
 bundled dialects (names subject to change):
-L<Muldis::D::Dialect::PTMD_STD>, L<Muldis::D::Dialect::HDMD_Perl6_STD>,
-L<Muldis::D::Dialect::HDMD_Perl5_STD>.
+L<Muldis::D::Outdated::Dialect::PTMD_STD>, L<Muldis::D::Outdated::Dialect::HDMD_Perl6_STD>,
+L<Muldis::D::Outdated::Dialect::HDMD_Perl5_STD>.
 
 =head2 Extensions
 
